@@ -1,6 +1,6 @@
 """Functions for parsing Amanzi/ATS XDMF visualization files.
 
-This file was copied from https://github.com/amanzi/ats/tree/master/tools/utils. For questions, please contact the following author.
+This file was modified from https://github.com/amanzi/ats/tree/master/tools/utils. For questions, please contact the following author.
 
 Author: Ethan Coon (ecoon@ornl.gov)
 """
@@ -31,7 +31,7 @@ def valid_mesh_filename(domain, format=None):
 
 class VisFile:
     """Class managing the reading of ATS visualization files."""
-    def __init__(self, directory='.', domain=None, filename=None, mesh_filename=None, model_time_unit='yr', return_time_unit='d'):
+    def __init__(self, directory='.', domain=None, prefix='ats_vis', model_time_unit='yr', return_time_unit='d', load_mesh=False, **kwargs):
         """Create a VisFile object.
 
         Parameters
@@ -40,6 +40,8 @@ class VisFile:
           Directory containing vis files.  Default is '.'
         domain : str, optional
           Amanzi/ATS domain name.  Useful in variable names, filenames, and more.
+        prefix : str,
+          prefix for visdump file. Default is 'ats_vis'
         filename : str, optional
           Filename of h5 vis file.  Default is 'ats_vis_DOMAIN_data.h5'.
           (e.g. ats_vis_surface_data.h5).
@@ -49,6 +51,11 @@ class VisFile:
           Time unit used for the h5 vis file. Default is year.
         return_time_unit: str, default is 'd'
           Time unit used for returned object self.times. Default is 'd'
+        load_mesh, bool
+            load mesh files if true. Default to False.
+        columnar, bool
+            If true, reorder 3D meshes to a "structured in z" mesh. Return shape of (ntriangles-per-layer, nlayers, ndim).
+            See loadMesh() for more information.
 
         Returns
         -------
@@ -57,19 +64,26 @@ class VisFile:
         self.directory = directory
         self.domain = domain
 
-        self.filename = filename
-        if self.filename is None:
-            if self.domain is None:
-                self.filename = 'ats_vis_data.h5'
-            else:
-                self.filename = 'ats_vis_{}_data.h5'.format(self.domain)
+        if self.domain is None:
+            self.filename = f'{prefix}_data.h5'
+            self.mesh_filename = f'{prefix}_mesh.h5'
+        else:
+            self.filename =f'{prefix}_{self.domain}_data.h5'
+            self.mesh_filename = f'{prefix}_{self.domain}_mesh.h5'
 
-        self.mesh_filename = mesh_filename
-        if self.mesh_filename is None:
-            if self.domain is None:
-                self.mesh_filename = 'ats_vis_mesh.h5'
-            else:
-                self.mesh_filename = 'ats_vis_{}_mesh.h5'.format(self.domain)
+        # self.filename = filename
+        # if self.filename is None:
+        #     if self.domain is None:
+        #         self.filename = 'ats_vis_data.h5'
+        #     else:
+        #         self.filename = 'ats_vis_{}_data.h5'.format(self.domain)
+
+        # self.mesh_filename = mesh_filename
+        # if self.mesh_filename is None:
+        #     if self.domain is None:
+        #         self.mesh_filename = 'ats_vis_mesh.h5'
+        #     else:
+        #         self.mesh_filename = 'ats_vis_{}_mesh.h5'.format(self.domain)
 
         if model_time_unit == 'yr':
             if return_time_unit == 'yr':
@@ -107,6 +121,13 @@ class VisFile:
         self.d = h5py.File(self.fname,'r')
         self.loadTimes()
         self.map = None
+
+        if load_mesh:
+            self.loadMesh(**kwargs)
+            etype, vertex_coords, conn = meshXYZ(self.directory, self.mesh_filename)
+            self.etype = etype
+            self.vertex_xyz = np.array(list(vertex_coords.values()))
+            self.conn = conn
         
     def __enter__(self):
         return self
@@ -269,6 +290,9 @@ class VisFile:
         """
         vname = self.variable(vname)
         logging.debug(f"get variable: {vname}")
+        # if vname does not exist, raise an error!
+        if vname not in list(self.d.keys()):
+            raise RuntimeError(f"Variable: {vname} is not found in vis file!")
         val = np.array([self._get(vname, k) for k in self.cycles])
         if self.map is None:
             return val
